# Table of Contents

- [sap-leanix-architecture-and-road-map-planning](<./sap-leanix-architecture-and-road-map-planning.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP LeanIX Architecture and Road Map Planning](<./SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
  - [Overview](<./SAP-LeanIX-Architecture-and-Road-Map-Planning/Overview.md>)
  - [Key Capabilities of SAP LeanIX Architecture and Road Map Planning](<./SAP-LeanIX-Architecture-and-Road-Map-Planning/Key-Capabilities-of-SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
  - [Introduction to SAP LeanIX Architecture and Road Map Planning](<./SAP-LeanIX-Architecture-and-Road-Map-Planning/Introduction-to-SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
  - [Transformation Insights from SAP LeanIX Architecture and Road Map Planning](<./SAP-LeanIX-Architecture-and-Road-Map-Planning/Transformation-Insights-from-SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
